//	Maze4D-HueBlend.fs

//	Technical Note:  Using a texture lookup to convert hue to RGB
//	is faster than using the high-quality algorithmic shader
//	(see "scraps/<AppName?>-Content - SLOW VERSION.fs")
//	but slower than the low-quality algorithmic shader
//	(see "scraps/<AppName?>-Content - FAST VERSION.fs").
//	For a hypercube on my first-generation iPad,
//	with NUM_REFINEMENTS=4 for the ball, the frame rates are
//
//		~22fps	high-quality algorithmic shader
//		~38fps	this texture-lookup shader
//		~52fps	low-quality algorithmic shader

uniform sampler2D	uniTexture;		//	automatically initialized to 0

in float	varHue,
			varDiffuseFactor,
			varSpecularFactor,
			varFogFactor;	//	0.0 = no fog; 1.0 = full fog

void main()
{
	vec3	tmpUnshadedColor,
			tmpShadedColor,
			tmpHighlightedColor,
			tmpFoggedColor;

	tmpUnshadedColor	= texture(uniTexture, vec2(varHue, 0.5)).rgb;
	tmpShadedColor		= varDiffuseFactor * tmpUnshadedColor;
	tmpHighlightedColor	= tmpShadedColor
						+ vec3(varSpecularFactor, varSpecularFactor, varSpecularFactor);
	tmpFoggedColor		= (1.0 - varFogFactor) * tmpHighlightedColor;

	gl_FragColor = vec4(tmpFoggedColor, 1.0);	//	premultiplied (αR,αG,αB,α)
}
