//	Maze4D-HueBlend.vs

uniform vec3	uniScaleFactors;	//	scales position vectors, but not normal vectors
uniform float	uniHueA,
				uniHueB;
uniform mat4	uniModelViewMatrix,
				uniModelViewProjectionMatrix;
uniform vec3	uniDiffuseEvaluator,
				uniSpecularEvaluator;

in vec3			atrPosition;
in vec3			atrNormal;
in float		atrWeight;

out float		varHue,
				varDiffuseFactor,
				varSpecularFactor,
				varFogFactor;	//	0.0 = no fog; 1.0 = full fog

void main()
{
	vec3	tmpPosition;
	vec4	tmpWorldPosition;

	tmpPosition			= atrPosition * uniScaleFactors;
	gl_Position			= uniModelViewProjectionMatrix * vec4(tmpPosition, 1.0);
	
	//	Don't really need full matrix computation, just z-component of the result.
	tmpWorldPosition	= uniModelViewMatrix * vec4(tmpPosition, 1.0);
	varFogFactor		= 0.25 * clamp(tmpWorldPosition.z, 0.0, 1.0);

	varHue				= (1.0 - atrWeight) * uniHueA
						+ (   atrWeight   ) * uniHueB;
	
	varDiffuseFactor	= 0.50 + 0.50 * max(0.0, dot(uniDiffuseEvaluator, atrNormal));
	varSpecularFactor	= 0.25 * pow(max(0.0, dot(uniSpecularEvaluator, atrNormal)), 16.0);
}
